@@ -9,7 +9,7 @@
  * #  Verwendung in anderen Programmen bzw. Programmiersprachen benutzt     #
  * #  werden.                                                               #
  * #                                                                        #
- * #  Copyright (C) 2002-2014 Michael Plugge <m.plugge@hs-mannheim.de>      #
+ * #  Copyright (C) 2002-2023 Michael Plugge <konto_check@yahoo.com>        #
  * #                                                                        #
  * #  Dieses Programm ist freie Software; Sie drfen es unter den           #
  * #  Bedingungen der GNU Lesser General Public License, wie von der Free   #
@@ -46,14 +46,6 @@
 #ifndef KONTO_CHECK_H_INCLUDED
 #define KONTO_CHECK_H_INCLUDED
 
-/* IBAN-Regeln benutzen (gltig ab 3.6.2013) */
-#define USE_IBAN_RULES 1
-
-   /* nderungen der Prfziffermethoden zum 9. September 2013 erzwingen
-    * (bei 0 werden sie abhngig vom Datum aktiviert; aktuell nicht benutzt).
-   */ 
-#define FORCE_AENDERUNGEN_2013_09 0
-
    /* Falls EXTRA_BLZ_REGEL auf 1 gesetzt wird, wird beim IBAN-Test
     * unterschieden ob eine Regel ignoriert wurde, die nur eine BLZ ersetzt,
     * oder eine andere Regel. Die Variante wenn nur eine BLZ ersetzt wird, wird
@@ -84,7 +76,10 @@
  * einige Arrays damit initialisiert werden.
  */
 
-#define DEFAULT_ENCODING 1
+#ifndef DEFAULT_ENCODING
+#  define DEFAULT_ENCODING 1
+#endif
+
 #define KEEP_RAW_DATA    1
 
 /* 
@@ -172,17 +167,19 @@
 
 #if _WIN32>0 || _WIN64>0
 #  if USE_CDECL
-#    if BUILD_DLL /* DLL kompilieren */
-#      define DLL_EXPORT __declspec (dllexport)
-#      define DLL_EXPORT_V __declspec (dllexport)
-#    elif USE_DLL /* DLL in einem anderen Programm benutzen */
-#      define DLL_EXPORT __declspec (dllimport)
-#      define DLL_EXPORT_V __declspec (dllimport)
-#    else /* kein DLL-Krempel erforderlich */
-#      define DLL_EXPORT
-#      define DLL_EXPORT_V
-#    endif
+#     define STDCALL
+#     if BUILD_DLL /* DLL kompilieren */
+#       define DLL_EXPORT __declspec (dllexport)
+#       define DLL_EXPORT_V __declspec (dllexport)
+#     elif USE_DLL /* DLL in einem anderen Programm benutzen */
+#       define DLL_EXPORT __declspec (dllimport)
+#       define DLL_EXPORT_V __declspec (dllimport)
+#     else /* kein DLL-Krempel erforderlich */
+#       define DLL_EXPORT
+#       define DLL_EXPORT_V
+#     endif
 #  else
+#     define STDCALL __stdcall
 #     if BUILD_DLL /* DLL kompilieren */
 #      define DLL_EXPORT __declspec (dllexport) __stdcall 
 #      define DLL_EXPORT_V __declspec (dllexport)
@@ -190,12 +187,13 @@
 #      define DLL_EXPORT __declspec (dllimport) __stdcall 
 #      define DLL_EXPORT_V __declspec (dllimport)
 #    else /* kein DLL-Krempel erforderlich */
-#      define DLL_EXPORT
+#      define DLL_EXPORT __stdcall
 #      define DLL_EXPORT_V
 #    endif
 #  endif
 #  define localtime_r(timep,result) localtime(timep)
 #else
+#  define STDCALL
 #  define DLL_EXPORT
 #  define DLL_EXPORT_V
 #endif
@@ -291,6 +289,11 @@
 #define LUT2_IBAN_REGEL              25
 #define LUT2_IBAN_REGEL_SORT         26
 #define LUT2_BIC_H_SORT              27
+#define LUT2_SCL_INFO                28
+#define LUT2_SCL_BIC                 29
+#define LUT2_SCL_NAME                30
+#define LUT2_SCL_FLAGS               31
+#define LUT2_SCL_FLAGS_ORIG          32
 
 #define LUT2_2_BLZ                  101
 #define LUT2_2_FILIALEN             102
@@ -319,6 +322,11 @@
 #define LUT2_2_IBAN_REGEL           125
 #define LUT2_2_IBAN_REGEL_SORT      126
 #define LUT2_2_BIC_H_SORT           127
+#define LUT2_2_SCL_INFO             128
+#define LUT2_2_SCL_BIC              129
+#define LUT2_2_SCL_NAME             130
+#define LUT2_2_SCL_FLAGS            131
+#define LUT2_2_SCL_FLAGS_ORIG       132
 
 #define LUT2_DEFAULT                501
 
@@ -335,6 +343,14 @@ extern const char *lut2_feld_namen[256];
  */
 
 #undef FALSE
+#define NO_SCL_BLOCKS_LOADED                  -158
+#define NO_SCL_INFO_BLOCK                     -157
+#define SCL_BIC_NOT_FOUND                     -156
+#define INVALID_SCL_INFO_BLOCK                -155
+#define NO_SCL_BLOCKS                         -154
+#define SCL_INPUT_FORMAT_ERROR                -153
+#define INVALID_REGULAR_EXPRESSION_CNT        -152
+#define INVALID_REGULAR_EXPRESSION            -151
 #define INVALID_HANDLE                        -150
 #define INVALID_BIQ_INDEX                     -149
 #define ARRAY_INDEX_OUT_OF_RANGE              -148
@@ -486,6 +502,8 @@ extern const char *lut2_feld_namen[256];
 #define OK_KTO_REPLACED_NO_PZ                   24
 #define OK_UNTERKONTO_ATTACHED                  25
 #define OK_SHORT_BIC_USED                       26
+#define OK_SCL_EXTENSION_BIC_USED               27
+#define OK_SCL_WILDCARD_BIC_USED                28
 
 #define MAX_BLZ_CNT 30000  /* maximale Anzahl BLZ's in generate_lut() */
 
@@ -653,7 +671,7 @@ DLL_EXPORT const char *kto_check_str(char *x_blz,char *kto,char *lut_name);
  * #    blz:        Bankleitzahl (immer 8-stellig)                           #
  * #    kto:        Kontonummer                                              #
  * #                                                                         #
- * # Copyright (C) 2007 Michael Plugge <m.plugge@hs-mannheim.de>             #
+ * # Copyright (C) 2007 Michael Plugge <konto_check@yahoo.com>               #
  * ###########################################################################
  */
 
@@ -675,7 +693,7 @@ DLL_EXPORT int kto_check_blz_dbg(char *blz,char *kto,RETVAL *retvals);
  * #    blz:        Bankleitzahl (immer 8-stellig)                           #
  * #    kto:        Kontonummer                                              #
  * #                                                                         #
- * # Copyright (C) 2007 Michael Plugge <m.plugge@hs-mannheim.de>             #
+ * # Copyright (C) 2007 Michael Plugge <konto_check@yahoo.com>               #
  * ###########################################################################
  */
 
@@ -711,7 +729,7 @@ DLL_EXPORT int kto_check_pz_dbg(char *pz,char *kto,char *blz,RETVAL *retvals);
  * #    retvals:    Struktur, in der die benutzte Prfziffermethode und die  #
  * #                berechnete Prfziffer zurckgegeben werden               #
  * #                                                                         #
- * # Copyright (C) 2013 Michael Plugge <m.plugge@hs-mannheim.de>             #
+ * # Copyright (C) 2013 Michael Plugge <konto_check@yahoo.com>               #
  * ###########################################################################
  */
 DLL_EXPORT int kto_check_regel(char *blz,char *kto);
@@ -859,6 +877,7 @@ DLL_EXPORT int lut_info_id(char *lut_name,int *info1,int *info2,int *valid1,int
 DLL_EXPORT const char *current_lutfile_name(int *set,int *level,int *retval);
 DLL_EXPORT int current_lutfile_name_id(int *set,int *level,int *retval);
 DLL_EXPORT int lut_valid(void);
+DLL_EXPORT int lut_valid_date(char *lut_name,int *v11,int *v12,int *v21,int *v22);
 DLL_EXPORT int get_lut_info2(char *lut_name,int *version_p,char **prolog_p,char **info_p,char **user_info_p);
 DLL_EXPORT int get_lut_info_b(char **info,char *lutname);
 DLL_EXPORT int get_lut_info2_b(char *lutname,int *version,char **prolog_p,char **info_p,char **user_info_p);
@@ -1093,6 +1112,24 @@ DLL_EXPORT int iban_name_id(char *iban,int filiale,int*retval);
 DLL_EXPORT int iban_name_kurz_id(char *iban,int filiale,int*retval);
 DLL_EXPORT int iban_ort_id(char *iban,int filiale,int*retval);
 
+   /* Funktionen fr das SCL-Verzeichnis */
+DLL_EXPORT int lut_scl_init(char *lut_name);
+DLL_EXPORT int lut_scl_info(char *lutfile,int *cnt,const char **gueltigkeit,const char **gueltigkeit_iso);
+DLL_EXPORT int lut_write_scl_blocks(char *inputfile,char *lutfile);
+DLL_EXPORT int lut_scl_multi(char *bic,const char **scl_flags,const char **used_bic,const char **scl_name);
+DLL_EXPORT int lut_scl_multi_blz(char *blz,const char **scl_flags,const char **used_bic,const char **scl_name);
+DLL_EXPORT int lut_scl_multi_blz_i(int blz,const char **scl_flags,const char **used_bic,const char **scl_name);
+DLL_EXPORT int lut_scl_sct(char *bic,int *retval);
+DLL_EXPORT int lut_scl_sdd(char *bic,int *retval);
+DLL_EXPORT int lut_scl_cor1(char *bic,int *retval);
+DLL_EXPORT int lut_scl_b2b(char *bic,int *retval);
+DLL_EXPORT int lut_scl_scc(char *bic,int *retval);
+DLL_EXPORT int lut_scl_sct_blz(char *blz,int *retval,const char **used_bic);
+DLL_EXPORT int lut_scl_sdd_blz(char *blz,int *retval,const char **used_bic);
+DLL_EXPORT int lut_scl_cor1_blz(char *blz,int *retval,const char **used_bic);
+DLL_EXPORT int lut_scl_b2b_blz(char *blz,int *retval,const char **used_bic);
+DLL_EXPORT int lut_scl_scc_blz(char *blz,int *retval,const char **used_bic);
+
 /*
  * ######################################################################
  * #               globale Variablen                                    #
